@@ -1,5 +1,5 @@
 package App::JESP::Cmd::Command::install;
-$App::JESP::Cmd::Command::install::VERSION = '0.007';
+$App::JESP::Cmd::Command::install::VERSION = '0.008';
 use base qw/App::JESP::Cmd::CommandJESP/;
 use strict; use warnings;
 use Log::Any qw/$log/;
@@ -24,7 +24,7 @@ sub abstract { "Install jesp in DB" }
 sub description { "Install jesp's metadata tables in the target database" }
 sub execute {
     my ($self, $opt, $args) = @_;
-    $self->{__jesp}->install();
+    $self->jesp->install();
 }
 
 1;
